@@ -191,7 +191,7 @@ class MultiTest(object):
 
         vals = self._pvals / self._uu
         self._istar = np.argmin(vals)
-        return vals[self._istar], self._pvals[self._istar]
+        return -np.log(vals[self._istar] + MIN_PVAL), self._pvals[self._istar]
 
     def fisher(self):
         """
@@ -205,5 +205,5 @@ class MultiTest(object):
             :Fs:       Fisher's method statistics
         """
         
-        Fs = np.mean(-2 * np.log(self._pvals))
+        Fs = np.mean(-2 * np.log(self._pvals + MIN_PVAL))
         return Fs
